@@ -27,6 +27,8 @@ from time import time
 from getpass import getuser
 from signal import signal, SIGINT, SIGTERM
 import gc
+import os
+import shutil
 
 from eolie.application_night import NightApplication
 from eolie.settings import Settings
@@ -202,6 +204,10 @@ class Application(Gtk.Application, NightApplication):
         if self.sync_worker is not None:
             self.sync_worker.stop()
             self.sync_worker.save_pendings()
+
+        if os.path.exists(self.favicons_path):
+            shutil.rmtree(self.favicons_path)
+
         if GLib.environ_getenv(GLib.get_environ(), "DEBUG_LEAK") is not None:
             gc.collect()
             for x in gc.garbage:
